@@ -1,7 +1,4 @@
 """I/O for UCSC Browser Extensible Data (BED)."""
-from __future__ import absolute_import, division, print_function
-from builtins import map, next
-
 import shlex
 
 import pandas as pd
